==> aptechka-0.41.6.tgz: package/lib/slicer/index.js <==
var T = (i) => {
  throw TypeError(i);
};
var A = (i, t, s) => t.has(i) || T("Cannot " + s);
var e = (i, t, s) => (A(i, t, "read from private field"), s ? s.call(i) : t.get(i)), l = (i, t, s) => t.has(i) ? T("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(i) : t.set(i, s), h = (i, t, s, a) => (A(i, t, "write to private field"), a ? a.call(i, s) : t.set(i, s), s), m = (i, t, s) => (A(i, t, "access private method"), s);
import { Media as v } from "../media/index.js";
var L, o;
class P {
  constructor(t) {
    l(this, L);
    l(this, o);
    h(this, L, t.index), h(this, o, document.createElement("span")), e(this, o).classList.add("letter"), t.clone ? e(this, o).innerHTML = `
        <span class="original">${t.text}</span>
        <span class="clone" aria-hidden>${t.text}</span>
      ` : e(this, o).innerHTML = `
        <span class="value">${t.text}</span>
      `;
  }
  get index() {
    return e(this, L);
  }
  get element() {
    return e(this, o);
  }
}
L = new WeakMap(), o = new WeakMap();
var y, r, u, g;
class $ {
  constructor(t) {
    l(this, y);
    l(this, r);
    l(this, u);
    l(this, g);
    h(this, y, t.index), h(this, r, document.createElement("span")), h(this, u, []), h(this, g, t.text.endsWith("\\n")), e(this, g) && (t.text = t.text.replace("\\n", "")), t.letters && t.lettersAcc !== void 0 ? (h(this, u, t.text.split("").map((s, a) => new P({
      index: t.lettersAcc + a,
      text: s,
      clone: t.clone
    }))), e(this, r).append(...e(this, u).map((s) => s.element))) : t.clone ? e(this, r).innerHTML = `
          <span class="original">${t.text}</span>
          <span class="clone" aria-hidden>${t.text}</span>
        ` : e(this, r).innerHTML = `
          <span class="value">${t.text}</span>
        `, e(this, r).classList.add("word");
  }
  get index() {
    return e(this, y);
  }
  get element() {
    return e(this, r);
  }
  get letters() {
    return e(this, u);
  }
  get hasNewLine() {
    return e(this, g);
  }
}
y = new WeakMap(), r = new WeakMap(), u = new WeakMap(), g = new WeakMap();
var p, c, x, f, d, M, E;
class C extends HTMLElement {
  constructor() {
    super(...arguments);
    l(this, d);
    l(this, p, "");
    l(this, c, []);
    l(this, x, []);
    l(this, f, null);
  }
  get wordsArray() {
    return e(this, c);
  }
  get lettersArray() {
    return e(this, x);
  }
  get originalHTML() {
    return e(this, p);
  }
  connectedCallback() {
    h(this, p, this.innerHTML.trim()), this.hasAttribute("media") ? (h(this, f, new v(this.getAttribute("media"))), e(this, f).subscribe((s) => {
      s.current ? m(this, d, M).call(this) : !s.current && s.previous && m(this, d, E).call(this);
    })) : m(this, d, M).call(this);
  }
  disconnectedCallback() {
    var s;
    m(this, d, E).call(this), (s = e(this, f)) == null || s.close();
  }
}
p = new WeakMap(), c = new WeakMap(), x = new WeakMap(), f = new WeakMap(), d = new WeakSet(), M = function() {
  const s = [];
  h(this, c, []);
  let a = 0, H = 0;
  this.childNodes.forEach((n) => {
    n.nodeName === "#text" && n.textContent ? n.textContent.trim().replace(/  +/g, " ").split(" ").map((b) => {
      const w = new $({
        index: a,
        text: b + " ",
        letters: this.hasAttribute("letters"),
        lettersAcc: H,
        clone: this.hasAttribute("clone")
      });
      H += w.letters.length, a += 1, e(this, x).push(...w.letters), e(this, c).push(w), s.push(w.element);
    }) : s.push(n);
  }), this.hasAttribute("index") && (e(this, c).forEach((n) => {
    n.element.style.setProperty("--word-index", n.index.toString());
  }), e(this, x).forEach((n) => {
    n.element.style.setProperty(
      "--letter-index",
      n.index.toString()
    );
  })), this.innerHTML = "", s.forEach((n) => {
    this.appendChild(n);
  }), this.style.setProperty("--words-length", e(this, c).length.toString()), this.style.setProperty("--letters-length", e(this, x).length.toString());
}, E = function() {
  h(this, c, []), this.innerHTML = e(this, p), this.style.removeProperty("--words-length"), this.style.removeProperty("--letters-length");
};
customElements.get("e-slicer") || customElements.define("e-slicer", C);
export {
  P as Letter,
  C as SlicerElement,
  $ as Word
};

==> aptechka-0.47.11.tgz: package/lib/slicer/index.js <==
var T = (i) => {
  throw TypeError(i);
};
var A = (i, t, s) => t.has(i) || T("Cannot " + s);
var e = (i, t, s) => (A(i, t, "read from private field"), s ? s.call(i) : t.get(i)), l = (i, t, s) => t.has(i) ? T("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(i) : t.set(i, s), h = (i, t, s, a) => (A(i, t, "write to private field"), a ? a.call(i, s) : t.set(i, s), s), m = (i, t, s) => (A(i, t, "access private method"), s);
import { Media as v } from "../media/index.js";
import { i as P } from "../index-euf5anj6.js";
var L, o;
class $ {
  constructor(t) {
    l(this, L);
    l(this, o);
    h(this, L, t.index), h(this, o, document.createElement("span")), e(this, o).classList.add("letter"), t.clone ? e(this, o).innerHTML = `
        <span class="original">${t.text}</span>
        <span class="clone" aria-hidden>${t.text}</span>
      ` : e(this, o).innerHTML = `
        <span class="value">${t.text}</span>
      `;
  }
  get index() {
    return e(this, L);
  }
  get element() {
    return e(this, o);
  }
}
L = new WeakMap(), o = new WeakMap();
var y, r, u, g;
class C {
  constructor(t) {
    l(this, y);
    l(this, r);
    l(this, u);
    l(this, g);
    h(this, y, t.index), h(this, r, document.createElement("span")), h(this, u, []), h(this, g, t.text.endsWith("\\n")), e(this, g) && (t.text = t.text.replace("\\n", "")), t.letters && t.lettersAcc !== void 0 ? (h(this, u, t.text.split("").map((s, a) => new $({
      index: t.lettersAcc + a,
      text: s,
      clone: t.clone
    }))), e(this, r).append(...e(this, u).map((s) => s.element))) : t.clone ? e(this, r).innerHTML = `
          <span class="original">${t.text}</span>
          <span class="clone" aria-hidden>${t.text}</span>
        ` : e(this, r).innerHTML = `
          <span class="value">${t.text}</span>
        `, e(this, r).classList.add("word");
  }
  get index() {
    return e(this, y);
  }
  get element() {
    return e(this, r);
  }
  get letters() {
    return e(this, u);
  }
  get hasNewLine() {
    return e(this, g);
  }
}
y = new WeakMap(), r = new WeakMap(), u = new WeakMap(), g = new WeakMap();
var p, c, x, f, d, M, E;
class S extends HTMLElement {
  constructor() {
    super(...arguments);
    l(this, d);
    l(this, p, "");
    l(this, c, []);
    l(this, x, []);
    l(this, f, null);
  }
  get wordsArray() {
    return e(this, c);
  }
  get lettersArray() {
    return e(this, x);
  }
  get originalHTML() {
    return e(this, p);
  }
  connectedCallback() {
    h(this, p, this.innerHTML.trim()), this.hasAttribute("media") ? (h(this, f, new v(this.getAttribute("media"))), e(this, f).subscribe((s) => {
      s.current ? m(this, d, M).call(this) : !s.current && s.previous && m(this, d, E).call(this);
    })) : m(this, d, M).call(this);
  }
  disconnectedCallback() {
    var s;
    m(this, d, E).call(this), (s = e(this, f)) == null || s.close();
  }
}
p = new WeakMap(), c = new WeakMap(), x = new WeakMap(), f = new WeakMap(), d = new WeakSet(), M = function() {
  const s = [];
  h(this, c, []);
  let a = 0, H = 0;
  this.childNodes.forEach((n) => {
    n.nodeName === "#text" && n.textContent ? n.textContent.trim().replace(/  +/g, " ").split(" ").map((b) => {
      const w = new C({
        index: a,
        text: b + " ",
        letters: this.hasAttribute("letters"),
        lettersAcc: H,
        clone: this.hasAttribute("clone")
      });
      H += w.letters.length, a += 1, e(this, x).push(...w.letters), e(this, c).push(w), s.push(w.element);
    }) : s.push(n);
  }), this.hasAttribute("index") && (e(this, c).forEach((n) => {
    n.element.style.setProperty("--word-index", n.index.toString());
  }), e(this, x).forEach((n) => {
    n.element.style.setProperty(
      "--letter-index",
      n.index.toString()
    );
  })), this.innerHTML = "", s.forEach((n) => {
    this.appendChild(n);
  }), this.style.setProperty("--words-length", e(this, c).length.toString()), this.style.setProperty("--letters-length", e(this, x).length.toString());
}, E = function() {
  h(this, c, []), this.innerHTML = e(this, p), this.style.removeProperty("--words-length"), this.style.removeProperty("--letters-length");
};
P && !customElements.get("e-slicer") && customElements.define("e-slicer", S);
export {
  $ as Letter,
  S as SlicerElement,
  C as Word
};
